@@ -1,6 +1,6 @@
 #! /bin/sh
 
-# $Id: autogen.sh,v 1.3 2006/01/10 19:25:07 murrayc Exp $
+# $Id: autogen.sh,v 1.4 2006/05/15 18:15:57 murrayc Exp $
 #
 # Copyright (c) 2002  Daniel Elstner  <daniel.elstner@gmx.net>,
 #               2003  Murray Cumming  <murrayc@usa.net>
@@ -60,14 +60,14 @@ echo "- libtoolize."		&& \
   libtoolize --copy --force --automake 	&& \
 echo "- gnome-doc-prepare."	&& \
   gnome-doc-prepare --force 	&& \
-echo "- aclocal"		&& \
-  aclocal -I "$srcdir/macros" $ACLOCAL_FLAGS && \
-echo "- autoheader"		&& \
-  autoheader			&& \
-echo "- autoconf."		&& \
-  autoconf			&& \
-echo "- automake."		&& \
-  automake --add-missing --gnu	&& \
+echo "- aclocal-1.9"		&& \
+  aclocal-1.9 -I "$srcdir/macros" $ACLOCAL_FLAGS && \
+echo "- autoheader2.50"		&& \
+  autoheader2.50			&& \
+echo "- autoconf2.50."		&& \
+  autoconf2.50			&& \
+echo "- automake-1.9."		&& \
+  automake-1.9 --add-missing --gnu	&& \
 echo "- configure --enable-maintainer-mode" $enable_warnings "$@"	&& \
   ./configure --enable-maintainer-mode $enable_warnings "$@"		&& exit 0
 
