@@ -23,13 +23,13 @@
 
 #include "gtkmm.h"
 
-#include "document/document_glom.h"
-#include "connectionpool.h"
-#include "appstate.h"
-#include "data_structure/privileges.h"
-#include "data_structure/system_prefs.h"
-#include "utils.h"
-#include "mode_data/calcinprogress.h"
+#include <glom/libglom/document/document_glom.h>
+#include <glom/libglom/connectionpool.h>
+#include <glom/libglom/appstate.h>
+#include <glom/libglom/data_structure/privileges.h>
+#include <glom/libglom/data_structure/system_prefs.h>
+#include <glom/libglom/utils.h>
+#include <glom/libglom/calcinprogress.h>
 #include "bakery/View/View.h"
 #include <bakery/Utilities/BusyCursor.h>
 
@@ -92,7 +92,7 @@ public:
   static Glib::ustring util_title_from_string(const Glib::ustring& text);
 
   //This is const because const means not changing this instance, not whether we change the database.
-  virtual Glib::RefPtr<Gnome::Gda::DataModel> Query_execute(const Glib::ustring& strQuery, Gtk::Window* parent_window = 0) const;
+  virtual Glib::RefPtr<Gnome::Gda::DataModel> query_execute(const Glib::ustring& strQuery, Gtk::Window* parent_window = 0) const;
 
   bool add_standard_groups();
   bool add_standard_tables() const;
@@ -102,6 +102,7 @@ public:
   bool insert_example_data(const Glib::ustring& table_name) const;
 
   typedef std::vector< sharedptr<LayoutItem_Field> > type_vecLayoutFields;
+  typedef std::vector< sharedptr<const LayoutItem_Field> > type_vecConstLayoutFields;
 
 protected:
   sharedptr<LayoutItem_Field> offer_field_list(const Glib::ustring& table_name, Gtk::Window* transient_for = 0);
@@ -188,37 +189,67 @@ protected:
     Gnome::Gda::Value m_key_value;
   };
 
+
+  class LayoutFieldInRecord
+  {
+  public:
+    LayoutFieldInRecord()
+    {}
+
+    LayoutFieldInRecord(const sharedptr<const LayoutItem_Field>& layout_item, const Glib::ustring& parent_table_name, const sharedptr<const Field>& parent_key, const Gnome::Gda::Value& key_value)
+    : m_key_value(key_value)
+    {
+      m_field = layout_item;
+      m_table_name = parent_table_name;
+      m_key = parent_key;
+    }
+
+    FieldInRecord get_fieldinrecord(const Document_Glom& document) const
+    {
+      return FieldInRecord(m_field, m_table_name, m_key, m_key_value, document);
+    }
+
+    //Identify the field:
+    Glib::ustring m_table_name;
+    sharedptr<const LayoutItem_Field> m_field;
+
+    //Identify the record:
+    sharedptr<const Field> m_key;
+    Gnome::Gda::Value m_key_value;
+  };
+
   /** Calculate values for fields, set them in the database, and show them in the layout.
    * @param field_changed The field that has changed, causing other fields to be recalculated because they use its value.
    * @param primary_key The primary key field for this table.
    * @param priamry_key_value: The primary key value for this record.
    * @param first_calc_field: false if this is called recursively.
    */
-  void do_calculations(const FieldInRecord& field_changed, bool first_calc_field);
+  void do_calculations(const LayoutFieldInRecord& field_changed, bool first_calc_field);
 
   typedef std::map<Glib::ustring, CalcInProgress> type_field_calcs;
 
+  typedef std::list< sharedptr<LayoutItem_Field> > type_list_field_items;
+  typedef std::list< sharedptr<const LayoutItem_Field> > type_list_const_field_items;
+
   /** Get the fields whose values should be recalculated when @a field_name changes.
    */
-  type_field_calcs get_calculated_fields(const Glib::ustring& table_name, const Glib::ustring& field_name);
-
-  typedef std::list< sharedptr<LayoutItem_Field> > type_list_field_items;
+  type_list_const_field_items get_calculated_fields(const Glib::ustring& table_name, const sharedptr<const LayoutItem_Field>& field);
 
   /** Get the fields used, if any, in the calculation of this field.
    */
-  type_list_field_items get_calculation_fields(const Glib::ustring& table_name, const sharedptr<const Field>& field);
+  type_list_const_field_items get_calculation_fields(const Glib::ustring& table_name, const sharedptr<const LayoutItem_Field>& field);
 
-  void calculate_field(const FieldInRecord& field_in_record);
+  void calculate_field(const LayoutFieldInRecord& field_in_record);
 
   void calculate_field_in_all_records(const Glib::ustring& table_name, const sharedptr<const Field>& field);
   void calculate_field_in_all_records(const Glib::ustring& table_name, const sharedptr<const Field>& field, const sharedptr<const Field>& primary_key);
 
   typedef std::map<Glib::ustring, Gnome::Gda::Value> type_map_fields;
   //TODO: Performance: This is massively inefficient:
-  type_map_fields get_record_field_values(const Glib::ustring& table_name, const sharedptr<const Field> primary_key, const Gnome::Gda::Value& primary_key_value);
+  type_map_fields get_record_field_values_for_calculation(const Glib::ustring& table_name, const sharedptr<const Field> primary_key, const Gnome::Gda::Value& primary_key_value);
 
 
-  void do_lookups(const FieldInRecord& field_in_record, const Gtk::TreeModel::iterator& row, const Gnome::Gda::Value& field_value);
+  void do_lookups(const LayoutFieldInRecord& field_in_record, const Gtk::TreeModel::iterator& row, const Gnome::Gda::Value& field_value);
 
   typedef std::pair< sharedptr<LayoutItem_Field>, sharedptr<Relationship> > type_pairFieldTrigger;
   typedef std::list<type_pairFieldTrigger> type_list_lookups;
@@ -234,12 +265,15 @@ protected:
   Gnome::Gda::Value get_lookup_value(const Glib::ustring& table_name, const sharedptr<const Relationship>& relationship, const sharedptr<const Field>& source_field, const Gnome::Gda::Value & key_value);
 
 
-  virtual void refresh_related_fields(const FieldInRecord& field_in_record_changed, const Gtk::TreeModel::iterator& row, const Gnome::Gda::Value& field_value);
+  virtual void refresh_related_fields(const LayoutFieldInRecord& field_in_record_changed, const Gtk::TreeModel::iterator& row, const Gnome::Gda::Value& field_value);
 
 
 
-  bool set_field_value_in_database(const FieldInRecord& field_in_record, const Gnome::Gda::Value& field_value, bool use_current_calculations = false, Gtk::Window* parent_window = 0);
-  bool set_field_value_in_database(const FieldInRecord& field_in_record, const Gtk::TreeModel::iterator& row, const Gnome::Gda::Value& field_value, bool use_current_calculations = false, Gtk::Window* parent_window = 0);
+  bool set_field_value_in_database(const LayoutFieldInRecord& field_in_record, const Gnome::Gda::Value& field_value, bool use_current_calculations = false, Gtk::Window* parent_window = 0);
+  bool set_field_value_in_database(const LayoutFieldInRecord& field_in_record, const Gtk::TreeModel::iterator& row, const Gnome::Gda::Value& field_value, bool use_current_calculations = false, Gtk::Window* parent_window = 0);
+
+  //Get a single field value from the database.
+  Gnome::Gda::Value get_field_value_in_database(const LayoutFieldInRecord& field_in_record, Gtk::Window* parent_window);
 
 
   type_vecStrings get_database_groups() const;
@@ -285,6 +319,11 @@ protected:
    */
   void recalculate_next_auto_increment_value(const Glib::ustring& table_name, const Glib::ustring& field_name) const;
 
+  bool get_field_value_is_unique(const Glib::ustring& table_name, const sharedptr<const LayoutItem_Field>& field, const Gnome::Gda::Value& value);
+
+  bool check_entered_value_for_uniqueness(const Glib::ustring& table_name, const sharedptr<const LayoutItem_Field>& field, const Gnome::Gda::Value& value, Gtk::Window* parent_window);
+  bool check_entered_value_for_uniqueness(const Glib::ustring& table_name, const Gtk::TreeModel::iterator& /* row */,  const sharedptr<const LayoutItem_Field>& field, const Gnome::Gda::Value& value, Gtk::Window* parent_window);
+
   virtual bool fill_from_database();
   virtual void fill_end(); //Call this from the end of fill_from_database() overrides.
 
@@ -312,9 +351,14 @@ protected:
    */
   bool postgres_add_column(const Glib::ustring& table_name, const sharedptr<const Field>& field, bool not_extras = false) const;
 
-  /** @param set_anyway If this is true, then set the extra details even if @field_old has the same properties.
+  /**
+   * @param table_name The name of the table that will be affected.
+   * @param field_old The definition of the field that will be changed.
+   * @param field The new definition to give the field.
+   * @param set_anyway If this is true, then set the extra details even if @field_old has the same properties.
+   * @result The new field definition, with any necessary changes.
    */
-  void postgres_change_column_extras(const Glib::ustring& table_name, const sharedptr<const Field>& field_old, const sharedptr<const Field>& field, bool set_anyway = false) const;
+  sharedptr<Field> postgres_change_column_extras(const Glib::ustring& table_name, const sharedptr<const Field>& field_old, const sharedptr<const Field>& field, bool set_anyway = false) const;
 
   void handle_error(const std::exception& ex) const; //TODO_port: This is probably useless now.
   bool handle_error() const;
