@@ -23,11 +23,13 @@
 
 #include <gtkmm.h>
 #include "../utility_widgets/dialog_properties.h"
-#include "../document/document_glom.h"
+#include <glom/libglom/document/document_glom.h>
 #include "../box_db.h"
 #include "../utility_widgets/combo_textglade.h"
 #include "../utility_widgets/comboentry_currency.h"
 #include "dialog_groupby_secondaryfields.h"
+#include "dialog_groupby_sortfields.h"
+#include "comboentry_borderwidth.h"
 
 
 class Dialog_GroupBy
@@ -50,18 +52,24 @@ public:
 protected:
   //Signal handlers:
   void on_button_field_group_by();
+  void on_button_formatting_group_by();
   void on_button_field_sort_by();
   void on_button_secondary_fields();
   void on_dialog_secondary_fields_hide();
 
+  void update_labels();
+
   Gtk::Label* m_label_group_by;
   Gtk::Label* m_label_sort_by;
   Gtk::Label* m_label_secondary_fields;
   Gtk::Button* m_button_field_group_by;
+  Gtk::Button* m_button_formatting_group_by;
   Gtk::Button* m_button_field_sort_by;
   Gtk::Button* m_button_secondary_fields;
+  ComboEntry_BorderWidth* m_comboboxentry_border_width;
 
   Dialog_GroupBy_SecondaryFields* m_dialog_choose_secondary_fields;
+  Dialog_GroupBy_SortFields* m_dialog_choose_sort_fields;
 
   mutable sharedptr<LayoutItem_GroupBy> m_layout_item;
 
