@@ -123,8 +123,17 @@ void Box_Data::on_Button_Find()
     signal_find_criteria.emit(where_clause);
 }
 
-
 Glib::RefPtr<Gnome::Gda::DataModel> Box_Data::record_new(bool use_entered_data, const Gnome::Gda::Value& primary_key_value)
+{
+  return record_new(use_entered_data, primary_key_value, Gtk::TreeModel::iterator());
+}
+
+void Box_Data::set_primary_key_value(const Gtk::TreeModel::iterator& row, const Gnome::Gda::Value& value)
+{
+  //Box_Data_List overrides this.
+}
+
+Glib::RefPtr<Gnome::Gda::DataModel> Box_Data::record_new(bool use_entered_data, const Gnome::Gda::Value& primary_key_value, const Gtk::TreeModel::iterator& row)
 {
   sharedptr<const Field> fieldPrimaryKey = get_field_primary_key();
 
@@ -147,6 +156,8 @@ Glib::RefPtr<Gnome::Gda::DataModel> Box_Data::record_new(bool use_entered_data,
     }
   }
 
+  Document_Glom* document = get_document();
+
   //Calculate any necessary field values and enter them:
   for(type_vecLayoutFields::const_iterator iter = fieldsToAdd.begin(); iter != fieldsToAdd.end(); ++iter)
   {
@@ -164,10 +175,9 @@ Glib::RefPtr<Gnome::Gda::DataModel> Box_Data::record_new(bool use_entered_data,
         if(field->get_has_calculation())
         {
           const Glib::ustring calculation = field->get_calculation();
-          const type_map_fields field_values = get_record_field_values(m_table_name, fieldPrimaryKey, primary_key_value);
+          const type_map_fields field_values = get_record_field_values_for_calculation(m_table_name, fieldPrimaryKey, primary_key_value);
 
-          const Gnome::Gda::Value value = glom_evaluate_python_function_implementation(field->get_glom_type(), calculation, field_values,
-            get_document(), m_table_name);
+          const Gnome::Gda::Value value = glom_evaluate_python_function_implementation(field->get_glom_type(), calculation, field_values, document, m_table_name);
           set_entered_field_data(layout_item, value);
         }
 
@@ -219,6 +229,17 @@ Glib::RefPtr<Gnome::Gda::DataModel> Box_Data::record_new(bool use_entered_data,
               value = get_entered_field_data(layout_item);
           }
 
+          /* //TODO: This would be too many small queries when adding one record.
+          //Check whether the value meets uniqueness constraints:
+          if(field->get_primary_key() || field->get_unique_key())
+          {
+            if(!get_field_value_is_unique(m_table_name, layout_item, value))
+            {
+              //Ignore this field value. TODO: Warn the user about it.
+            } 
+          }
+          */
+
           Glib::ustring strFieldValue = field->sql(value);
 
           if(!strFieldValue.empty())
@@ -240,13 +261,39 @@ Glib::RefPtr<Gnome::Gda::DataModel> Box_Data::record_new(bool use_entered_data,
   }
 
   //Put it all together to create the record with these field values:
+  Glib::RefPtr<Gnome::Gda::DataModel> result;
   if(!strNames.empty() && !strValues.empty())
   {
-    Glib::ustring strQuery = "INSERT INTO \"" + m_table_name + "\" (" + strNames + ") VALUES (" + strValues + ")";
-    return Query_execute(strQuery, get_app_window());
+    const Glib::ustring strQuery = "INSERT INTO \"" + m_table_name + "\" (" + strNames + ") VALUES (" + strValues + ")";
+    result = query_execute(strQuery, get_app_window());
+    if(result)
+    {
+      set_primary_key_value(row, primary_key_value); //Needed by Box_Data_List::on_adddel_user_changed().
+
+      //Update any lookups, related fields, or calculations:
+      for(type_vecLayoutFields::const_iterator iter = fieldsToAdd.begin(); iter != fieldsToAdd.end(); ++iter)
+      {
+         sharedptr<const LayoutItem_Field> layout_item = *iter;
+         
+         //TODO_Performance: We just set this with set_entered_field_data() above. Maybe we could just remember it.
+         const Gnome::Gda::Value field_value = get_entered_field_data(layout_item);
+
+         LayoutFieldInRecord field_in_record(layout_item, m_table_name, fieldPrimaryKey, primary_key_value);
+
+         //Get-and-set values for lookup fields, if this field triggers those relationships:
+         do_lookups(field_in_record, row, field_value);
+
+         //Update related fields, if this field is used in the relationship:
+         refresh_related_fields(field_in_record, row, field_value);
+      }
+    }
+    else
+    {
+      std::cerr << "Box_Data::record_new(): INSERT returned null DataModel." << std::endl; 
+    }
   }
-  else
-    return Glib::RefPtr<Gnome::Gda::DataModel>();
+
+  return result; //Failed.
 }
 
 void Box_Data::set_unstored_data(bool bVal)
@@ -342,7 +389,7 @@ Gnome::Gda::Value Box_Data::generate_next_auto_increment(const Glib::ustring& ta
   //This is a workaround for postgres problems. Ideally, we need to use the postgres serial type and find out how to get the generated value after we add a row.
 
   double result = 0;
-  Glib::RefPtr<Gnome::Gda::DataModel> data_model = Query_execute("SELECT max(" + field_name + ") FROM \"" + table_name + "\"");
+  Glib::RefPtr<Gnome::Gda::DataModel> data_model = query_execute("SELECT max(" + field_name + ") FROM \"" + table_name + "\"");
   if(!data_model && data_model->get_n_rows())
     handle_error();
   else
@@ -367,13 +414,14 @@ Gnome::Gda::Value Box_Data::generate_next_auto_increment(const Glib::ustring& ta
 
 /** Get the shown fields that are in related tables, via a relationship using @a field_name changes.
  */
-Box_Data::type_vecLayoutFields Box_Data::get_related_fields(const Glib::ustring& field_name) const
+Box_Data::type_vecLayoutFields Box_Data::get_related_fields(const sharedptr<const LayoutItem_Field>& field) const
 {
   type_vecLayoutFields result;
 
   const Document_Glom* document = dynamic_cast<const Document_Glom*>(get_document());
   if(document)
   {
+    const Glib::ustring field_name = field->get_name(); //At the moment, relationships can not be based on related fields on the from side.
     for(type_vecLayoutFields::const_iterator iter = m_FieldsShown.begin(); iter != m_FieldsShown.end();  ++iter)
     {
       sharedptr<LayoutItem_Field> layout_field = *iter;
@@ -398,21 +446,21 @@ Box_Data::type_vecLayoutFields Box_Data::get_related_fields(const Glib::ustring&
   return result;
 }
 
-void Box_Data::refresh_related_fields(const FieldInRecord& field_in_record_changed, const Gtk::TreeModel::iterator& row, const Gnome::Gda::Value& field_value)
+void Box_Data::refresh_related_fields(const LayoutFieldInRecord& field_in_record_changed, const Gtk::TreeModel::iterator& row, const Gnome::Gda::Value& field_value)
 {
   if(field_in_record_changed.m_table_name != m_table_name)
     return; //TODO: Handle these too?
 
   //Get values for lookup fields, if this field triggers those relationships:
   //TODO_performance: There is a LOT of iterating and copying here.
-  const Glib::ustring strFieldName = field_in_record_changed.m_field->get_name();
-  type_vecLayoutFields fieldsToGet = get_related_fields(strFieldName);
+  //const Glib::ustring strFieldName = field_in_record_changed.m_field->get_name();
+  type_vecLayoutFields fieldsToGet = get_related_fields(field_in_record_changed.m_field);
 
   if(!fieldsToGet.empty())
   {
     const Glib::ustring query = GlomUtils::build_sql_select_with_key(field_in_record_changed.m_table_name, fieldsToGet, field_in_record_changed.m_key, field_in_record_changed.m_key_value);
 
-    Glib::RefPtr<Gnome::Gda::DataModel> result = Query_execute(query, get_app_window());
+    Glib::RefPtr<Gnome::Gda::DataModel> result = query_execute(query, get_app_window());
     if(!result)
     {
       g_warning("Box_Data_List::refresh_related_fields(): no result.");
@@ -536,7 +584,7 @@ bool Box_Data::record_delete(const Gnome::Gda::Value& primary_key_value)
   sharedptr<Field> field_primary_key = get_field_primary_key();
   if(field_primary_key && !GlomConversions::value_is_empty(primary_key_value))
   {
-    return Query_execute( "DELETE FROM \"" + m_table_name + "\" WHERE \"" + m_table_name + "\".\"" + field_primary_key->get_name() + "\" = " + field_primary_key->sql(primary_key_value), get_app_window());
+    return query_execute( "DELETE FROM \"" + m_table_name + "\" WHERE \"" + m_table_name + "\".\"" + field_primary_key->get_name() + "\" = " + field_primary_key->sql(primary_key_value), get_app_window());
   }
   else
   {
@@ -636,7 +684,7 @@ bool Box_Data::get_related_record_exists(const sharedptr<const Relationship>& re
 
   //TODO_Performance: Is this the best way to just find out whether there is one record that meets this criteria?
   const Glib::ustring query = "SELECT \"" + to_field + "\" FROM \"" + relationship->get_to_table() + "\" WHERE \"" + to_field + "\" = " + key_field->sql(key_value);
-  Glib::RefPtr<Gnome::Gda::DataModel> records = Query_execute(query, get_app_window());
+  Glib::RefPtr<Gnome::Gda::DataModel> records = query_execute(query, get_app_window());
   if(!records)
     handle_error();
   else
@@ -708,7 +756,7 @@ bool Box_Data::add_related_record_for_field(const sharedptr<const LayoutItem_Fie
         }
 
         const Glib::ustring strQuery = "INSERT INTO \"" + relationship->get_to_table() + "\" (\"" + primary_key_field->get_name() + "\") VALUES (" + primary_key_field->sql(primary_key_value) + ")";
-        bool test = Query_execute(strQuery, get_app_window());
+        bool test = query_execute(strQuery, get_app_window());
         if(test)
         {
           if(key_is_auto_increment)
@@ -742,7 +790,7 @@ bool Box_Data::add_related_record_for_field(const sharedptr<const LayoutItem_Fie
                 {
                   const Glib::ustring strQuery = "UPDATE \"" + relationship->get_from_table() + "\" SET \"" + relationship->get_from_field() + "\" = " + primary_key_field->sql(primary_key_value) +
                     " WHERE \"" + relationship->get_from_table() + "\".\"" + parent_primary_key_field->get_name() + "\" = " + parent_primary_key_field->sql(parent_primary_key_value);
-                  const bool test = Query_execute(strQuery, get_app_window());
+                  const bool test = query_execute(strQuery, get_app_window());
                   return test;
                 }
               }
