@@ -19,11 +19,13 @@
  */
 
 #include "box_data_details.h"
-#include "../data_structure/field.h"
-#include "../data_structure/relationship.h"
-#include "../data_structure/glomconversions.h"
+#include "../frame_glom.h" //For show_ok_dialog().
+#include <glom/libglom/data_structure/field.h>
+#include <glom/libglom/data_structure/relationship.h>
+#include <glom/libglom/data_structure/glomconversions.h>
 #include "dialog_layout_details.h"
-#include "../utils.h"
+#include <glom/libglom/utils.h>
+#include "../xsl_utils.h"
 #include <bakery/App/App_Gtk.h> //For util_bold_message().
 #include "../python_embed/glom_python.h"
 #include <sstream> //For stringstream
@@ -133,6 +135,11 @@ Gnome::Gda::Value Box_Data_Details::get_primary_key_value() const
   return m_primary_key_value;
 }
 
+void Box_Data_Details::set_primary_key_value(const Gtk::TreeModel::iterator& /* row */, const Gnome::Gda::Value& value)
+{
+  m_primary_key_value = value;
+}
+
 bool Box_Data_Details::init_db_details(const FoundSet& found_set, const Gnome::Gda::Value& primary_key_value)
 {
   //std::cout << "Box_Data_Details::init_db_details(): primary_key_value.to_string()=" << primary_key_value.to_string() << std::endl;
@@ -193,6 +200,12 @@ bool Box_Data_Details::fill_from_database()
   if(!primary_key_is_empty)
     get_document()->set_layout_record_viewed(m_table_name, m_layout_name, m_primary_key_value);
 
+  if(!m_field_primary_key)
+  {
+    //refresh_data_from_database_blank(); //shows blank record
+    return false;
+  }
+
   try
   {
 
@@ -229,7 +242,7 @@ bool Box_Data_Details::fill_from_database()
         Glib::RefPtr<Gnome::Gda::DataModel> result;
 
         if(!primary_key_is_empty)
-          result = Query_execute(query, get_app_window());
+          result = query_execute(query, get_app_window());
 
         if((result && result->get_n_rows()) || primary_key_is_empty) //either a working result or no result needed.
         {
@@ -391,6 +404,7 @@ void Box_Data_Details::recalculate_fields_for_related_records(const Glib::ustrin
 {
   m_FieldsCalculationInProgress.clear();
 
+  //Check all fields in the parent table:
   const Gnome::Gda::Value primary_key_value = get_primary_key_value();
   for(type_vecFields::iterator iter = m_TableFields.begin(); iter != m_TableFields.end(); ++iter)
   {
@@ -404,7 +418,9 @@ void Box_Data_Details::recalculate_fields_for_related_records(const Glib::ustrin
       sharedptr<Field> field = *iter;
       if(field)
       {
-        FieldInRecord field_in_record(m_table_name, field, m_field_primary_key, primary_key_value);
+        sharedptr<LayoutItem_Field> layoutitem_field = sharedptr<LayoutItem_Field>::create();
+        layoutitem_field->set_full_field_details(field);
+        LayoutFieldInRecord field_in_record(layoutitem_field, m_table_name, m_field_primary_key, primary_key_value);
         calculate_field(field_in_record); //And any dependencies.
 
         //Calculate anything that depends on this.
@@ -528,7 +544,7 @@ void Box_Data_Details::on_flowtable_script_button_clicked(const sharedptr<const
   if(layout_item)
   {
     const Gnome::Gda::Value primary_key_value = get_primary_key_value();
-    const type_map_fields field_values = get_record_field_values(m_table_name, m_field_primary_key, primary_key_value);
+    const type_map_fields field_values = get_record_field_values_for_calculation(m_table_name, m_field_primary_key, primary_key_value);
 
     glom_execute_python_function_implementation(layout_item->get_script(), field_values, //TODO: Maybe use the field's type here.
     get_document(), get_table_name());
@@ -542,6 +558,10 @@ void Box_Data_Details::on_flowtable_field_edited(const sharedptr<const LayoutIte
 
   const Glib::ustring strFieldName = layout_field->get_name();
 
+  Gtk::Window* window = get_app_window();
+
+  Document_Glom* document = dynamic_cast<Document_Glom*>(get_document());
+
   Gnome::Gda::Value primary_key_value = get_primary_key_value();
   if(!GlomConversions::value_is_empty(primary_key_value)) //If there is not a primary key value:
   {
@@ -561,8 +581,6 @@ void Box_Data_Details::on_flowtable_field_edited(const sharedptr<const LayoutIte
       //plus how to identify the record in that table.
       const Glib::ustring relationship_name = layout_field->get_relationship_name();
 
-      Document_Glom* document = dynamic_cast<Document_Glom*>(get_document());
-
       sharedptr<Relationship> relationship = document->get_relationship(get_table_name(), relationship_name);
       if(relationship)
       {
@@ -594,23 +612,28 @@ void Box_Data_Details::on_flowtable_field_edited(const sharedptr<const LayoutIte
       }
     }
 
-    //const sharedptr<const Field>& field = layout_field->m_field;
+
+    LayoutFieldInRecord field_in_record(layout_field, m_table_name /* parent table */, primary_key_field, primary_key_value);
+
+    //Check whether the value meets uniqueness constraints:
+    if(!check_entered_value_for_uniqueness(m_table_name, layout_field, field_value, window))
+    {
+      //Revert to the value in the database:
+      const Gnome::Gda::Value value_old = get_field_value_in_database(field_in_record, window);
+      set_entered_field_data(layout_field, value_old);
+   
+      return; 
+    }
 
     //Set the value in all instances of this field in the layout (The field might be on the layout more than once):
     //if(layout_field->get_glom_type() != Field::TYPE_IMAGE) //TODO For now, don't do this for images, because the ImageGlom widget expects a broken GdaValue, because gda_value_get_binary() needs to be fixed.
-      m_FlowTable.set_field_value(layout_field, field_value);
+    m_FlowTable.set_field_value(layout_field, field_value);
 
     //Update the field in the record (the record with this primary key):
     try
     {
-      FieldInRecord field_in_record(layout_field, m_table_name /* parent table */, primary_key_field, primary_key_value, *(get_document()));
       const bool bTest = set_field_value_in_database(field_in_record, field_value, false /* don't use current calculations */, get_app_window());
 
-      //Glib::ustring strQuery = "UPDATE \"" + table_name + "\"";
-      //strQuery += " SET " +  /* table_name + "." + postgres does not seem to like the table name here */ strFieldName + " = " + field.sql(field_value);
-      //strQuery += " WHERE " + table_name + "." + primary_key_field.get_name() + " = " + primary_key_field.sql(primary_key_value);
-      //bool bTest = Query_execute(strQuery);
-
       if(!bTest)
       {
         //Update failed.
@@ -673,12 +696,21 @@ void Box_Data_Details::on_flowtable_field_edited(const sharedptr<const LayoutIte
     {
       //It is not auto-generated:
 
-      if(strFieldName == m_field_primary_key->get_name()) //if it is the primary key that' being edited.
+      if(strFieldName == m_field_primary_key->get_name()) //if it is the primary key that is being edited.
       {
-        //Create new record with this primary key,
-        //and all the other field values too.
-        //see comments after 'else':
-        record_new(true /* use entered field data */);
+        if(!check_entered_value_for_uniqueness(m_table_name, layout_field, field_value, window))
+        {
+          //Revert to a blank value:
+          const Gnome::Gda::Value value_old = GlomConversions::get_empty_value(layout_field->get_full_field_details()->get_glom_type());
+          set_entered_field_data(layout_field, value_old);
+        }
+        else
+        {
+          //Create new record with this primary key,
+          //and all the other field values too.
+          //see comments after 'else':
+          record_new(true /* use entered field data */);
+        }
       }
       else
       {
@@ -794,6 +826,6 @@ void Box_Data_Details::print_layout()
       print_layout_group(nodeParent, layout_group);
     }
 
-    GlomUtils::transform_and_open(*pDocument, "print_details_to_html.xsl", get_app_window());
+    GlomXslUtils::transform_and_open(*pDocument, "print_details_to_html.xsl", get_app_window());
   }
 }
