@@ -200,62 +200,60 @@ bool Box_Data_List_Related::fill_from_database()
   return result;
 }
 
-void Box_Data_List_Related::on_record_added(const Gnome::Gda::Value& primary_key_value)
+void Box_Data_List_Related::on_record_added(const Gnome::Gda::Value& primary_key_value, const Gtk::TreeModel::iterator& row)
 {
   //primary_key_value is a new autogenerated or human-entered key for the row.
   //It has already been added to the database.
 
-  //Get row of new record:
-  Gtk::TreeModel::iterator iter = m_AddDel.get_row(primary_key_value);
-  if(iter)
-  {
-    Gnome::Gda::Value key_value;
+  if(!row)
+    return;
 
+  Gnome::Gda::Value key_value;
+
+  if(m_key_field)
+  {
+    //m_key_field is the field in this table that must match another field in the parent table.
+    sharedptr<LayoutItem_Field> layout_item = sharedptr<LayoutItem_Field>::create();
+    layout_item->set_full_field_details(m_key_field);
+    key_value = m_AddDel.get_value(row, layout_item);
+  }
+
+  Box_Data_List::on_record_added(key_value, row); //adds blank row.
+
+  //Make sure that the new related record is related,
+  //by setting the foreign key:
+  //If it's not auto-generated.
+  if(!GlomConversions::value_is_empty(key_value)) //If there is already a value.
+  {
+    //It was auto-generated. Tell the parent about it, so it can make a link.
+    signal_record_added.emit(key_value);
+  }
+  else if(GlomConversions::value_is_empty(m_key_value))
+  {
+    g_warning("Box_Data_List_Related::on_record_added(): m_key_value is NULL.");
+  }
+  else
+  {
+    sharedptr<Field> field_primary_key = m_AddDel.get_key_field();
+
+    //Create the link by setting the foreign key
     if(m_key_field)
     {
-      //m_key_field is the field in this table that must match another field in the parent table.
-      sharedptr<LayoutItem_Field> layout_item = sharedptr<LayoutItem_Field>::create();
-      layout_item->set_full_field_details(m_key_field);
-      key_value = m_AddDel.get_value(iter, layout_item);
-    }
-
-    Box_Data_List::on_record_added(key_value); //adds blank row.
-
-    //Make sure that the new related record is related,
-    //by setting the foreign key:
-    //If it's not auto-generated.
-    if(!GlomConversions::value_is_empty(key_value)) //If there is already a value.
-    {
-      //It was auto-generated. Tell the parent about it, so it can make a link.
-      signal_record_added.emit(key_value);
-    }
-    else if(GlomConversions::value_is_empty(m_key_value))
-    {
-      g_warning("Box_Data_List_Related::on_record_added(): m_key_value is NULL.");
-    }
-    else
-    {
-      sharedptr<Field> field_primary_key = m_AddDel.get_key_field();
-
-      //Create the link by setting the foreign key
-      if(m_key_field)
+      Glib::ustring strQuery = "UPDATE \"" + m_portal->get_relationship()->get_to_table() + "\"";
+      strQuery += " SET \"" +  /* get_table_name() + "." +*/ m_key_field->get_name() + "\" = " + m_key_field->sql(m_key_value);
+      strQuery += " WHERE \"" + get_table_name() + "\".\"" + field_primary_key->get_name() + "\" = " + field_primary_key->sql(primary_key_value);
+      const bool test = query_execute(strQuery, get_app_window());
+      if(test)
       {
-        Glib::ustring strQuery = "UPDATE \"" + m_portal->get_relationship()->get_to_table() + "\"";
-        strQuery += " SET \"" +  /* get_table_name() + "." +*/ m_key_field->get_name() + "\" = " + m_key_field->sql(m_key_value);
-        strQuery += " WHERE \"" + get_table_name() + "\".\"" + field_primary_key->get_name() + "\" = " + field_primary_key->sql(primary_key_value);
-        bool test = Query_execute(strQuery, get_app_window());
-        if(test)
-        {
-          //Show it on the view, if it's visible:
-          sharedptr<LayoutItem_Field> layout_item = sharedptr<LayoutItem_Field>::create();
-          layout_item->set_full_field_details(field_primary_key);
+        //Show it on the view, if it's visible:
+        sharedptr<LayoutItem_Field> layout_item = sharedptr<LayoutItem_Field>::create();
+        layout_item->set_full_field_details(field_primary_key);
 
-          m_AddDel.set_value(iter, layout_item, m_key_value);
-        }
+        m_AddDel.set_value(row, layout_item, m_key_value);
       }
-
-      //on_adddel_user_changed(iter, iKey); //Update the database.
     }
+
+    //on_adddel_user_changed(row, iKey); //Update the database.
   }
 }
 
@@ -524,7 +522,7 @@ void Box_Data_List_Related::get_suitable_record_to_view_details(const Gnome::Gda
         //std::cout << "PRIMARY_KEY_VALUE=" << primary_key_value.to_string() << std::endl;
 
         const Glib::ustring query = GlomUtils::build_sql_select_with_key(LayoutWidgetBase::m_table_name, fieldsToGet, m_AddDel.get_key_field(), primary_key_value);
-        Glib::RefPtr<Gnome::Gda::DataModel> data_model = Query_execute(query);
+        Glib::RefPtr<Gnome::Gda::DataModel> data_model = query_execute(query);
         if(data_model && data_model->get_n_rows() && data_model->get_n_columns())
         {
           table_primary_key_value = data_model->get_value_at(0, 0);
