@@ -23,7 +23,7 @@
 
 #include <gtkmm/dialog.h>
 #include "../utility_widgets/dialog_properties.h"
-#include "../document/document_glom.h"
+#include <glom/libglom/document/document_glom.h>
 #include "../box_db.h"
 
 class Dialog_ChooseRelationship : public Gtk::Dialog
