@@ -44,10 +44,10 @@ Notebook_Data::Notebook_Data()
   m_Box_Details.signal_nav_last().connect(sigc::mem_fun(m_Box_List, &Box_Data_List::on_details_nav_last));
 
   //Allow Details to tell List about record deletion:
-  m_Box_Details.signal_record_deleted().connect(sigc::mem_fun(m_Box_List, &Box_Data_List::on_Details_record_deleted));
+  m_Box_Details.signal_record_deleted().connect(sigc::mem_fun(m_Box_List, &Box_Data_List::on_details_record_deleted));
 
   //Allow Details to ask to show a different record in a different table:
-  m_Box_Details.signal_requested_related_details().connect(sigc::mem_fun(*this, &Notebook_Data::on_Details_user_requested_related_details));
+  m_Box_Details.signal_requested_related_details().connect(sigc::mem_fun(*this, &Notebook_Data::on_details_user_requested_related_details));
 
   //Fill composite view:
   add_view(&m_Box_List);
@@ -62,9 +62,10 @@ Notebook_Data::~Notebook_Data()
   remove_view(&m_Box_Details);
 }
 
-bool Notebook_Data::init_db_details(const FoundSet& found_set)
+bool Notebook_Data::init_db_details(const FoundSet& found_set, const Gnome::Gda::Value& primary_key_value_for_details)
 {
   m_table_name = found_set.m_table_name;
+  const bool details_record_specified = !GlomConversions::value_is_empty(primary_key_value_for_details);
 
   bool result = false;
   //where_clause is only used as a result of a find.
@@ -88,11 +89,15 @@ bool Notebook_Data::init_db_details(const FoundSet& found_set)
     {
       Gnome::Gda::Value primary_key_for_details;
 
-      if(!new_find_set)
+      if(!new_find_set && !details_record_specified)
       {
         //std::cout << "debug: no new_found_set" << std::endl;
         primary_key_for_details = document->get_layout_record_viewed(m_table_name, m_Box_Details.get_layout_name());
       }
+      else if(details_record_specified)
+      {
+        primary_key_for_details = primary_key_value_for_details;
+      }
       else
       {
          //std::cout << "debug: new_found_set" << std::endl;
@@ -115,36 +120,44 @@ bool Notebook_Data::init_db_details(const FoundSet& found_set)
     }
   }
 
-  //Select the last-viewed layout:
-  bool found = false;
-  Document_Glom* document = get_document();
-  if(document)
+  //Select the last-viewed layout, or the details layout, if a specific details record was specified:
+  if(details_record_specified)
   {
-    const Glib::ustring current_layout = get_document()->get_layout_current(m_table_name);
-    if(!current_layout.empty())
+    set_current_page(m_iPage_Details);
+  }
+  else
+  {
+    //Select the last-viewed layout:
+    bool found = false;
+    Document_Glom* document = get_document();
+    if(document)
     {
-      const int count = get_n_pages();
-      int page = 0;
-      while(!found && (page < count))
+      const Glib::ustring current_layout = get_document()->get_layout_current(m_table_name);
+      if(!current_layout.empty())
       {
-        Box_Data* box = dynamic_cast<Box_Data*>(get_nth_page(page));
-        if(box && (box->get_layout_name() == current_layout))
-          found = true;
-        else
-          ++page;
-      }
+        const int count = get_n_pages();
+        int page = 0;
+        while(!found && (page < count))
+        {
+          Box_Data* box = dynamic_cast<Box_Data*>(get_nth_page(page));
+          if(box && (box->get_layout_name() == current_layout))
+            found = true;
+          else
+            ++page;
+        }
 
-      if(found)
-      {
-        set_current_page(page);
+        if(found)
+        {
+          set_current_page(page);
+        }
       }
     }
-  }
 
-  if(!found)
-  {
-    //Select List as default:
-    set_current_page(m_iPage_List);
+    if(!found)
+    {
+      //Select List as default:
+     set_current_page(m_iPage_List);
+    }
   }
 
   return result;
@@ -157,11 +170,12 @@ FoundSet Notebook_Data::get_found_set() const
 
 void Notebook_Data::on_list_user_requested_details(const Gnome::Gda::Value& primary_key_value)
 {
+  //std::cout << "Notebook_Data::on_list_user_requested_details" << std::endl;
   m_Box_Details.refresh_data_from_database_with_primary_key(primary_key_value);
   set_current_page(m_iPage_Details);
 }
 
-void Notebook_Data::on_Details_user_requested_related_details(const Glib::ustring& table_name, Gnome::Gda::Value primary_key_value)
+void Notebook_Data::on_details_user_requested_related_details(const Glib::ustring& table_name, Gnome::Gda::Value primary_key_value)
 {
   signal_record_details_requested().emit(table_name, primary_key_value);
 
@@ -176,6 +190,8 @@ void Notebook_Data::on_Details_user_requested_related_details(const Glib::ustrin
 
 void Notebook_Data::set_current_view(dataview view)
 {
+  std::cout << "Notebook_Data::set_current_view" << std::endl;
+
   if(view == DATA_VIEW_List)
     set_current_page(m_iPage_List);
   else
