@@ -23,7 +23,7 @@
 
 #include <gtkmm.h>
 #include "layoutwidgetbase.h"
-#include "../data_structure/layout/layoutitem_button.h"
+#include <glom/libglom/data_structure/layout/layoutitem_button.h>
 #include <libglademm.h>
 
 class App_Glom;
