@@ -22,10 +22,10 @@
 #define GLOM_DB_ADDDEL_H
 
 #include "gtkmm.h"
-#include "../../data_structure/layout/layoutitem_field.h"
+#include <glom/libglom/data_structure/layout/layoutitem_field.h>
 #include <libgdamm.h>
 #include "glom_db_treemodel.h"
-#include "../../document/document_glom.h"
+#include <glom/libglom/document/document_glom.h>
 
 #include <vector>
 #include <map>
@@ -103,8 +103,8 @@ public:
    * @param start_editing Whether editing should start in the cell.
    * @result Whether the row was successfully selected.
    */
-  bool select_item(const Gtk::TreeModel::iterator& iter, guint column, bool start_editing = false);  //bool indicates success.
-  bool select_item(const Gtk::TreeModel::iterator& iter);
+  bool select_item(const Gtk::TreeModel::iterator& iter, const sharedptr<const LayoutItem_Field>& layout_item, bool start_editing = false);  //bool indicates success.
+  bool select_item(const Gtk::TreeModel::iterator& iter, bool start_editing = false);
 
   guint get_count() const;
 
@@ -227,8 +227,7 @@ public:
   typedef sigc::signal<void> type_signal_user_reordered_columns;
   type_signal_user_reordered_columns signal_user_reordered_columns();
 
-  bool get_model_column_index(guint view_column_index, guint& model_column_index);
-
+ 
   virtual Gtk::TreeModel::iterator get_last_row();
   virtual Gtk::TreeModel::iterator get_last_row() const;
 
@@ -236,6 +235,9 @@ public:
 
 protected:
 
+  bool get_model_column_index(guint view_column_index, guint& model_column_index);
+
+
   typedef std::list<guint> type_list_indexes;
   ///Return the column indexes of any columns that display this field.
   virtual type_list_indexes get_column_index(const sharedptr<const LayoutItem_Field>& layout_item) const;
