@@ -37,7 +37,7 @@ public:
 
   virtual void remove(Gtk::Widget& first); //override
 
-  virtual void set_columns_count(guint value);
+  void set_columns_count(guint value);
 
   /** Sets the padding to put between the child widgets.
    */
@@ -81,7 +81,7 @@ protected:
 
     Gtk::Widget* m_first;
     Gtk::Widget* m_second;
-    bool m_expand_first;
+    bool m_expand_first_full;
     bool m_expand_second;
 
     //Cache the positions, so we can use them in on_expose_event:
